@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -13,7 +13,7 @@
 from gettext import gettext as tr
 
 from holidays.calendars import _CustomIslamicHolidays
-from holidays.calendars.gregorian import MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV
+from holidays.calendars.gregorian import MAR, MAY, JUN, AUG, SEP, OCT, NOV
 from holidays.groups import (
     ChristianHolidays,
     IslamicHolidays,
@@ -29,23 +29,23 @@ class Spain(
     """Spain holidays.
 
     References:
-        * <https://administracion.gob.es/pag_Home/atencionCiudadana/calendarios.html>
-        * [2010](https://www.boe.es/buscar/doc.php?id=BOE-A-2009-18477)
-        * [2011](https://www.boe.es/buscar/doc.php?id=BOE-A-2010-15722)
-        * [2012](https://www.boe.es/buscar/doc.php?id=BOE-A-2011-16116)
-        * [2013](https://www.boe.es/buscar/doc.php?id=BOE-A-2012-13644)
-        * [2014](https://www.boe.es/buscar/doc.php?id=BOE-A-2013-12147)
-        * [2015](https://www.boe.es/buscar/doc.php?id=BOE-A-2014-10823)
-        * [2016](https://www.boe.es/buscar/doc.php?id=BOE-A-2015-11348)
-        * [2017](https://www.boe.es/buscar/doc.php?id=BOE-A-2016-9244)
-        * [2018](https://www.boe.es/buscar/doc.php?id=BOE-A-2017-11639)
-        * [2019](https://www.boe.es/buscar/doc.php?id=BOE-A-2018-14369)
-        * [2020](https://www.boe.es/buscar/doc.php?id=BOE-A-2019-14552)
-        * [2021](https://www.boe.es/buscar/doc.php?id=BOE-A-2020-13343)
-        * [2022](https://www.boe.es/buscar/doc.php?id=BOE-A-2021-17113)
-        * [2023](https://www.boe.es/buscar/doc.php?id=BOE-A-2022-16755)
-        * [2024](https://www.boe.es/buscar/doc.php?id=BOE-A-2023-22014)
-        * [2025](https://www.boe.es/buscar/doc.php?id=BOE-A-2024-21316)
+        * <https://web.archive.org/web/20250407130530/https://administracion.gob.es/pag_Home/atencionCiudadana/calendarios.html>
+        * [2010](https://web.archive.org/web/20250427181827/https://www.boe.es/buscar/doc.php?id=BOE-A-2009-18477)
+        * [2011](https://web.archive.org/web/20231121065830/https://www.boe.es/buscar/doc.php?id=BOE-A-2010-15722)
+        * [2012](https://web.archive.org/web/20250427181838/https://www.boe.es/buscar/doc.php?id=BOE-A-2011-16116)
+        * [2013](https://web.archive.org/web/20220120080053/https://www.boe.es/buscar/doc.php?id=BOE-A-2012-13644)
+        * [2014](https://web.archive.org/web/20201001232243/https://www.boe.es/buscar/doc.php?id=BOE-A-2013-12147)
+        * [2015](https://web.archive.org/web/20240915041804/https://www.boe.es/buscar/doc.php?id=BOE-A-2014-10823)
+        * [2016](https://web.archive.org/web/20240915044403/http://www.boe.es/buscar/doc.php?id=BOE-A-2015-11348)
+        * [2017](https://web.archive.org/web/20170609094105/http://www.boe.es:80/buscar/doc.php?id=BOE-A-2016-9244)
+        * [2018](https://web.archive.org/web/20241006073402/https://www.boe.es/buscar/doc.php?id=BOE-A-2017-11639)
+        * [2019](https://web.archive.org/web/20240329020330/https://boe.es/buscar/doc.php?id=BOE-A-2018-14369)
+        * [2020](https://web.archive.org/web/20240417060155/https://www.boe.es/buscar/doc.php?id=BOE-A-2019-14552)
+        * [2021](https://web.archive.org/web/20241114022913/https://www.boe.es/buscar/doc.php?id=BOE-A-2020-13343)
+        * [2022](https://web.archive.org/web/20240725121311/https://www.boe.es/buscar/doc.php?id=BOE-A-2021-17113)
+        * [2023](https://web.archive.org/web/20240811035605/https://www.boe.es/buscar/doc.php?id=BOE-A-2022-16755)
+        * [2024](https://web.archive.org/web/20240401192304/https://www.boe.es/buscar/doc.php?id=BOE-A-2023-22014)
+        * [2025](https://web.archive.org/web/20241226214918/https://www.boe.es/buscar/doc.php?id=BOE-A-2024-21316)
 
     Holidays checked with official sources for 2010-2025 only.
     """
@@ -55,29 +55,52 @@ class Spain(
     # Monday following %s.
     observed_label = tr("Lunes siguiente a %s")
     subdivisions = (
-        "AN",  # Andalucía
-        "AR",  # Aragón
-        "AS",  # Asturias
-        "CB",  # Cantabria
-        "CE",  # Ceuta
-        "CL",  # Castilla y León
-        "CM",  # Castilla-La Mancha
-        "CN",  # Canarias
-        "CT",  # Cataluña
-        "EX",  # Extremadura
-        "GA",  # Galicia
-        "IB",  # Islas Baleares
-        "MC",  # Murcia
-        "MD",  # Madrid
-        "ML",  # Melilla
-        "NC",  # Navarra
-        "PV",  # País Vasco
-        "RI",  # La Rioja
-        "VC",  # Valenciana
+        "AN",  # Andalucía.
+        "AR",  # Aragón.
+        "AS",  # Asturias.
+        "CB",  # Cantabria.
+        "CE",  # Ceuta.
+        "CL",  # Castilla y León.
+        "CM",  # Castilla-La Mancha.
+        "CN",  # Canarias.
+        "CT",  # Cataluña (Catalunya).
+        "EX",  # Extremadura.
+        "GA",  # Galicia.
+        "IB",  # Islas Baleares (Illes Balears).
+        "MC",  # Murcia.
+        "MD",  # Madrid.
+        "ML",  # Melilla.
+        "NC",  # Navarra.
+        "PV",  # País Vasco.
+        "RI",  # La Rioja.
+        "VC",  # Valenciana.
     )
+    subdivisions_aliases = {
+        "Andalucía": "AN",
+        "Aragón": "AR",
+        "Asturias": "AS",
+        "Cantabria": "CB",
+        "Ceuta": "CE",
+        "Castilla y León": "CL",
+        "Castilla-La Mancha": "CM",
+        "Canarias": "CN",
+        "Cataluña": "CT",
+        "Catalunya": "CT",
+        "Extremadura": "EX",
+        "Galicia": "GA",
+        "Islas Baleares": "IB",
+        "Illes Balears": "IB",
+        "Murcia": "MC",
+        "Madrid": "MD",
+        "Melilla": "ML",
+        "Navarra": "NC",
+        "País Vasco": "PV",
+        "La Rioja": "RI",
+        "Valenciana": "VC",
+    }
     supported_languages = ("en_US", "es", "uk")
 
-    def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
+    def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
         """
         Args:
             islamic_show_estimated:
@@ -694,28 +717,21 @@ class ESP(Spain):
 
 
 class SpainIslamicHolidays(_CustomIslamicHolidays):
+    EID_AL_ADHA_DATES_CONFIRMED_YEARS = (2010, 2025)
     EID_AL_ADHA_DATES = {
         2010: (NOV, 17),
-        2011: (NOV, 6),
         2012: (OCT, 25),
-        2013: (OCT, 15),
-        2014: (OCT, 4),
         2015: (SEP, 25),
         2016: (SEP, 12),
-        2017: (SEP, 1),
         2018: (AUG, 22),
         2019: (AUG, 12),
-        2020: (JUL, 31),
-        2021: (JUL, 20),
-        2022: (JUL, 9),
         2023: (JUN, 29),
         2024: (JUN, 17),
-        2025: (JUN, 6),
     }
 
+    EID_AL_FITR_DATES_CONFIRMED_YEARS = (2022, 2025)
     EID_AL_FITR_DATES = {
         2022: (MAY, 3),
-        2023: (APR, 21),
         2025: (MAR, 31),
     }
 
