@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -21,11 +21,13 @@ RegistryDict = dict[str, tuple[str, ...]]
 
 COUNTRIES: RegistryDict = {
     "afghanistan": ("Afghanistan", "AF", "AFG"),
+    "aland_islands": ("AlandIslands", "AX", "ALA", "HolidaysAX"),
     "albania": ("Albania", "AL", "ALB"),
     "algeria": ("Algeria", "DZ", "DZA"),
     "american_samoa": ("AmericanSamoa", "AS", "ASM", "HolidaysAS"),
     "andorra": ("Andorra", "AD", "AND"),
     "angola": ("Angola", "AO", "AGO"),
+    "anguilla": ("Anguilla", "AI", "AIA"),
     "antigua_and_barbuda": ("AntiguaAndBarbuda", "AG", "ATG"),
     "argentina": ("Argentina", "AR", "ARG"),
     "armenia": ("Armenia", "AM", "ARM"),
@@ -40,22 +42,33 @@ COUNTRIES: RegistryDict = {
     "belarus": ("Belarus", "BY", "BLR"),
     "belgium": ("Belgium", "BE", "BEL"),
     "belize": ("Belize", "BZ", "BLZ"),
+    "benin": ("Benin", "BJ", "BEN"),
+    "bermuda": ("Bermuda", "BM", "BMU"),
+    "bhutan": ("Bhutan", "BT", "BTN"),
     "bolivia": ("Bolivia", "BO", "BOL"),
+    "bonaire_sint_eustatius_and_saba": ("BonaireSintEustatiusAndSaba", "BQ", "BES"),
     "bosnia_and_herzegovina": ("BosniaAndHerzegovina", "BA", "BIH"),
     "botswana": ("Botswana", "BW", "BWA"),
     "brazil": ("Brazil", "BR", "BRA"),
+    "british_virgin_islands": ("BritishVirginIslands", "VG", "VGB"),
     "brunei": ("Brunei", "BN", "BRN"),
     "bulgaria": ("Bulgaria", "BG", "BLG"),
     "burkina_faso": ("BurkinaFaso", "BF", "BFA"),
     "burundi": ("Burundi", "BI", "BDI"),
+    "cabo_verde": ("CaboVerde", "CV", "CPV"),
     "cambodia": ("Cambodia", "KH", "KHM"),
     "cameroon": ("Cameroon", "CM", "CMR"),
     "canada": ("Canada", "CA", "CAN"),
+    "cayman_islands": ("CaymanIslands", "KY", "CYM"),
+    "central_african_republic": ("CentralAfricanRepublic", "CF", "CAF"),
     "chad": ("Chad", "TD", "TCD"),
     "chile": ("Chile", "CL", "CHL"),
     "china": ("China", "CN", "CHN"),
+    "christmas_island": ("ChristmasIsland", "CX", "CXR"),
+    "cocos_islands": ("CocosIslands", "CC", "CCK"),
     "colombia": ("Colombia", "CO", "COL"),
     "congo": ("Congo", "CG", "COG"),
+    "cook_islands": ("CookIslands", "CK", "COK"),
     "costa_rica": ("CostaRica", "CR", "CRI"),
     "croatia": ("Croatia", "HR", "HRV"),
     "cuba": ("Cuba", "CU", "CUB"),
@@ -66,27 +79,39 @@ COUNTRIES: RegistryDict = {
     "djibouti": ("Djibouti", "DJ", "DJI"),
     "dominica": ("Dominica", "DM", "DMA"),
     "dominican_republic": ("DominicanRepublic", "DO", "DOM"),
+    "dr_congo": ("DRCongo", "CD", "COD"),
     "ecuador": ("Ecuador", "EC", "ECU"),
     "egypt": ("Egypt", "EG", "EGY"),
     "jordan": ("Jordan", "JO", "JOR"),
     "el_salvador": ("ElSalvador", "SV", "SLV"),
+    "equatorial_guinea": ("EquatorialGuinea", "GQ", "GNQ"),
     "estonia": ("Estonia", "EE", "EST"),
     "eswatini": ("Eswatini", "SZ", "SZW", "Swaziland"),
     "ethiopia": ("Ethiopia", "ET", "ETH"),
+    "falkland_islands": ("FalklandIslands", "FK", "FLK"),
+    "faroe_islands": ("FaroeIslands", "FO", "FRO"),
     "fiji": ("Fiji", "FJ", "FJI"),
     "finland": ("Finland", "FI", "FIN"),
     "france": ("France", "FR", "FRA"),
+    "french_guiana": ("FrenchGuiana", "GF", "GUF", "HolidaysGF"),
+    "french_polynesia": ("FrenchPolynesia", "PF", "PYF", "HolidaysPF"),
     "french_southern_territories": ("FrenchSouthernTerritories", "TF", "ATF", "HolidaysTF"),
     "gabon": ("Gabon", "GA", "GAB"),
+    "gambia": ("Gambia", "GM", "GMB"),
     "georgia": ("Georgia", "GE", "GEO"),
     "germany": ("Germany", "DE", "DEU"),
     "ghana": ("Ghana", "GH", "GHA"),
+    "gibraltar": ("Gibraltar", "GI", "GIB"),
     "greece": ("Greece", "GR", "GRC"),
     "greenland": ("Greenland", "GL", "GRL"),
+    "grenada": ("Grenada", "GD", "GRD"),
+    "guadeloupe": ("Guadeloupe", "GP", "GLP", "HolidaysGP"),
     "guam": ("Guam", "GU", "GUM", "HolidaysGU"),
     "guatemala": ("Guatemala", "GT", "GUA"),
     "guernsey": ("Guernsey", "GG", "GGY"),
     "guinea": ("Guinea", "GN", "GIN"),
+    "guinea_bissau": ("GuineaBissau", "GW", "GNB"),
+    "guyana": ("Guyana", "GY", "GUY"),
     "haiti": ("Haiti", "HT", "HTI"),
     "honduras": ("Honduras", "HN", "HND"),
     "hongkong": ("HongKong", "HK", "HKG"),
@@ -95,6 +120,7 @@ COUNTRIES: RegistryDict = {
     "india": ("India", "IN", "IND"),
     "indonesia": ("Indonesia", "ID", "IDN"),
     "iran": ("Iran", "IR", "IRN"),
+    "iraq": ("Iraq", "IQ", "IRQ"),
     "ireland": ("Ireland", "IE", "IRL"),
     "isle_of_man": ("IsleOfMan", "IM", "IMN"),
     "israel": ("Israel", "IL", "ISR"),
@@ -105,11 +131,15 @@ COUNTRIES: RegistryDict = {
     "jersey": ("Jersey", "JE", "JEY"),
     "kazakhstan": ("Kazakhstan", "KZ", "KAZ"),
     "kenya": ("Kenya", "KE", "KEN"),
+    "kiribati": ("Kiribati", "KI", "KIR"),
     "kuwait": ("Kuwait", "KW", "KWT"),
     "kyrgyzstan": ("Kyrgyzstan", "KG", "KGZ"),
     "laos": ("Laos", "LA", "LAO"),
     "latvia": ("Latvia", "LV", "LVA"),
+    "lebanon": ("Lebanon", "LB", "LBN"),
     "lesotho": ("Lesotho", "LS", "LSO"),
+    "liberia": ("Liberia", "LR", "LBR"),
+    "libya": ("Libya", "LY", "LBY"),
     "liechtenstein": ("Liechtenstein", "LI", "LIE"),
     "lithuania": ("Lithuania", "LT", "LTU"),
     "luxembourg": ("Luxembourg", "LU", "LUX"),
@@ -118,62 +148,98 @@ COUNTRIES: RegistryDict = {
     "malawi": ("Malawi", "MW", "MWI"),
     "malaysia": ("Malaysia", "MY", "MYS"),
     "maldives": ("Maldives", "MV", "MDV"),
+    "mali": ("Mali", "ML", "MLI"),
     "malta": ("Malta", "MT", "MLT"),
     "marshall_islands": ("MarshallIslands", "MH", "MHL", "HolidaysMH"),
+    "martinique": ("Martinique", "MQ", "MTQ", "HolidaysMQ"),
     "mauritania": ("Mauritania", "MR", "MRT"),
+    "mauritius": ("Mauritius", "MU", "MUS"),
+    "mayotte": ("Mayotte", "YT", "MYT", "HolidaysYT"),
     "mexico": ("Mexico", "MX", "MEX"),
+    "micronesia": ("Micronesia", "FM", "FSM"),
     "moldova": ("Moldova", "MD", "MDA"),
     "monaco": ("Monaco", "MC", "MCO"),
+    "mongolia": ("Mongolia", "MN", "MNG"),
     "montenegro": ("Montenegro", "ME", "MNE"),
+    "montserrat": ("Montserrat", "MS", "MSR"),
     "morocco": ("Morocco", "MA", "MOR"),
     "mozambique": ("Mozambique", "MZ", "MOZ"),
     "namibia": ("Namibia", "NA", "NAM"),
+    "nauru": ("Nauru", "NR", "NRU"),
+    "nepal": ("Nepal", "NP", "NPL"),
     "netherlands": ("Netherlands", "NL", "NLD"),
+    "new_caledonia": ("NewCaledonia", "NC", "NCL", "HolidaysNC"),
     "new_zealand": ("NewZealand", "NZ", "NZL"),
     "nicaragua": ("Nicaragua", "NI", "NIC"),
+    "niger": ("Niger", "NE", "NER"),
     "nigeria": ("Nigeria", "NG", "NGA"),
+    "niue": ("Niue", "NU", "NIU"),
+    "norfolk_island": ("NorfolkIsland", "NF", "NFK"),
     "north_macedonia": ("NorthMacedonia", "MK", "MKD"),
     "northern_mariana_islands": ("NorthernMarianaIslands", "MP", "MNP", "HolidaysMP"),
     "norway": ("Norway", "NO", "NOR"),
     "oman": ("Oman", "OM", "OMN"),
     "pakistan": ("Pakistan", "PK", "PAK"),
     "palau": ("Palau", "PW", "PLW"),
+    "palestine": ("Palestine", "PS", "PSE"),
     "panama": ("Panama", "PA", "PAN"),
     "papua_new_guinea": ("PapuaNewGuinea", "PG", "PNG"),
     "paraguay": ("Paraguay", "PY", "PRY"),
     "peru": ("Peru", "PE", "PER"),
     "philippines": ("Philippines", "PH", "PHL"),
+    "pitcairn_islands": ("PitcairnIslands", "PN", "PCN"),
     "poland": ("Poland", "PL", "POL"),
     "portugal": ("Portugal", "PT", "PRT"),
     "puerto_rico": ("PuertoRico", "PR", "PRI", "HolidaysPR"),
     "qatar": ("Qatar", "QA", "QAT"),
+    "reunion": ("Reunion", "RE", "REU", "HolidaysRE"),
     "romania": ("Romania", "RO", "ROU"),
     "russia": ("Russia", "RU", "RUS"),
+    "saint_barthelemy": ("SaintBarthelemy", "BL", "BLM", "HolidaysBL"),
     "saint_kitts_and_nevis": ("SaintKittsAndNevis", "KN", "KNA"),
     "saint_lucia": ("SaintLucia", "LC", "LCA"),
+    "saint_martin": ("SaintMartin", "MF", "MAF", "HolidaysMF"),
+    "saint_pierre_and_miquelon": ("SaintPierreAndMiquelon", "PM", "SPM", "HolidaysPM"),
+    "saint_vincent_and_the_grenadines": ("SaintVincentAndTheGrenadines", "VC", "VCT"),
     "samoa": ("Samoa", "WS", "WSM"),
     "san_marino": ("SanMarino", "SM", "SMR"),
+    "sao_tome_and_principe": ("SaoTomeAndPrincipe", "ST", "STP"),
     "saudi_arabia": ("SaudiArabia", "SA", "SAU"),
+    "senegal": ("Senegal", "SN", "SEN"),
     "serbia": ("Serbia", "RS", "SRB"),
     "seychelles": ("Seychelles", "SC", "SYC"),
     "sierra_leone": ("SierraLeone", "SL", "SLE"),
     "singapore": ("Singapore", "SG", "SGP"),
+    "sint_maarten": ("SintMaarten", "SX", "SXM"),
     "slovakia": ("Slovakia", "SK", "SVK"),
     "slovenia": ("Slovenia", "SI", "SVN"),
+    "solomon_islands": ("SolomonIslands", "SB", "SLB"),
     "south_africa": ("SouthAfrica", "ZA", "ZAF"),
+    "south_georgia_and_the_south_sandwich_islands": (
+        "SouthGeorgiaAndTheSouthSandwichIslands",
+        "GS",
+        "SGS",
+    ),
     "south_korea": ("SouthKorea", "KR", "KOR", "Korea"),
     "spain": ("Spain", "ES", "ESP"),
     "sri_lanka": ("SriLanka", "LK", "LKA"),
     "suriname": ("Suriname", "SR", "SUR"),
+    "svalbard_and_jan_mayen": ("SvalbardAndJanMayen", "SJ", "SJM", "HolidaysSJ"),
     "sweden": ("Sweden", "SE", "SWE"),
     "switzerland": ("Switzerland", "CH", "CHE"),
+    "syrian_arab_republic": ("SyrianArabRepublic", "SY", "SYR"),
     "taiwan": ("Taiwan", "TW", "TWN"),
     "tanzania": ("Tanzania", "TZ", "TZA"),
     "thailand": ("Thailand", "TH", "THA"),
     "timor_leste": ("TimorLeste", "TL", "TLS"),
+    "togo": ("Togo", "TG", "TGO"),
+    "tokelau": ("Tokelau", "TK", "TKL"),
     "tonga": ("Tonga", "TO", "TON"),
+    "trinidad_and_tobago": ("TrinidadAndTobago", "TT", "TTO"),
     "tunisia": ("Tunisia", "TN", "TUN"),
     "turkey": ("Turkey", "TR", "TUR"),
+    "turkmenistan": ("Turkmenistan", "TM", "TKM"),
+    "turks_and_caicos_islands": ("TurksAndCaicosIslands", "TC", "TCA"),
     "tuvalu": ("Tuvalu", "TV", "TUV"),
     "ukraine": ("Ukraine", "UA", "UKR"),
     "united_arab_emirates": ("UnitedArabEmirates", "AE", "ARE"),
@@ -192,6 +258,8 @@ COUNTRIES: RegistryDict = {
     "vatican_city": ("VaticanCity", "VA", "VAT"),
     "venezuela": ("Venezuela", "VE", "VEN"),
     "vietnam": ("Vietnam", "VN", "VNM"),
+    "wallis_and_futuna": ("WallisAndFutuna", "WF", "WLF", "HolidaysWF"),
+    "yemen": ("Yemen", "YE", "YEM"),
     "zambia": ("Zambia", "ZM", "ZMB"),
     "zimbabwe": ("Zimbabwe", "ZW", "ZWE"),
 }
