@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -24,7 +24,9 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
         super().setUpClass(Taiwan, years=years, years_non_observed=years)
         cls.government_holidays = Taiwan(categories=GOVERNMENT, years=years)
         cls.optional_holidays = Taiwan(categories=OPTIONAL, years=years)
-        cls.optional_holidays_observed = Taiwan(categories=OPTIONAL, years=years, observed=False)
+        cls.optional_holidays_non_observed = Taiwan(
+            categories=OPTIONAL, years=years, observed=False
+        )
         cls.school_holidays = Taiwan(categories=SCHOOL, years=years)
         cls.workday_holidays = Taiwan(categories=WORKDAY, years=years)
 
@@ -181,6 +183,9 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
             "2022-01-31",
             "2023-01-21",
             "2024-02-09",
+            "2025-01-28",
+            "2026-02-15",
+            "2026-02-16",
         )
         self.assertHolidayName(name_eve, range(1998, 2050))
         # CNY itself.
@@ -235,6 +240,7 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
             "2013-02-13",
             "2016-02-11",
             "2023-01-25",
+            "2026-02-20",
         )
         obs_dt = (
             "1998-01-31",
@@ -363,7 +369,7 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
             "2000-04-03",
         )
         self.assertHolidayName(f"{name}（慶祝）", self.optional_holidays, obs_dt)
-        self.assertNoNonObservedHoliday(self.optional_holidays_observed, obs_dt)
+        self.assertNoNonObservedHoliday(self.optional_holidays_non_observed, obs_dt)
 
         # Public Holidays.
         self.assertHolidayName(name, (f"{year}-04-04" for year in range(2011, 2050)))
@@ -397,7 +403,7 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
             "2000-04-03",
         )
         self.assertHolidayName(f"{name}（慶祝）", self.optional_holidays, obs_dt)
-        self.assertNoNonObservedHoliday(self.optional_holidays_observed, obs_dt)
+        self.assertNoNonObservedHoliday(self.optional_holidays_non_observed, obs_dt)
         self.assertNoHolidayName(name)
 
         # Workdays.
@@ -458,11 +464,15 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
     def test_labor_day(self):
         name = "勞動節"
 
+        # Public Holidays.
+        self.assertHolidayName(name, (f"{year}-05-01" for year in range(2026, 2050)))
+        self.assertNoHolidayName(name, range(1998, 2026))
+
         # Optional Holidays.
         self.assertHolidayName(
-            name, self.optional_holidays, (f"{year}-05-01" for year in range(1998, 2050))
+            name, self.optional_holidays, (f"{year}-05-01" for year in range(1998, 2026))
         )
-        self.assertNoHolidayName(name)
+        self.assertNoHolidayName(name, self.optional_holidays, range(2026, 2050))
 
     def test_the_buddhas_birthday(self):
         name = "佛陀誕辰紀念日"
@@ -541,7 +551,7 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
         )
         obs_dt = ("2000-09-04",)
         self.assertHolidayName(f"{name}（慶祝）", self.optional_holidays, obs_dt)
-        self.assertNoNonObservedHoliday(self.optional_holidays_observed, obs_dt)
+        self.assertNoNonObservedHoliday(self.optional_holidays_non_observed, obs_dt)
         self.assertNoHolidayName(name)
 
     def test_mid_autumn_festival(self):
@@ -587,6 +597,10 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
     def test_confucius_birthday(self):
         name = "孔子誕辰紀念日"
 
+        # Public Holidays.
+        self.assertHolidayName(name, (f"{year}-09-28" for year in range(2025, 2050)))
+        self.assertNoHolidayName(name, range(1998, 2025))
+
         # Government Holidays.
         self.assertHolidayName(
             name, self.government_holidays, (f"{year}-09-28" for year in range(1998, 2001))
@@ -601,10 +615,9 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
 
         # Workdays.
         self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-09-28" for year in range(2001, 2050))
+            name, self.workday_holidays, (f"{year}-09-28" for year in range(2001, 2025))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(1998, 2000))
-        self.assertNoHolidayName(name)
+        self.assertNoHolidayName(name, self.workday_holidays, range(1998, 2000), range(2025, 2050))
 
     def test_teachers_day(self):
         name = "教師節"
@@ -626,26 +639,33 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
         self.assertNoHolidayName(name)
 
     def test_taiwan_retrocession_day(self):
-        name = "臺灣光復節"
+        name_old = "臺灣光復節"
+        name_new = "臺灣光復暨金門古寧頭大捷紀念日"
+
+        # Public Holidays.
+        self.assertHolidayName(name_new, (f"{year}-10-25" for year in range(2025, 2050)))
+        self.assertNoHolidayName(name_new, range(1998, 2025))
+        self.assertNoHolidayName(name_old)
 
         # Government Holidays.
         self.assertHolidayName(
-            name, self.government_holidays, (f"{year}-10-25" for year in range(1998, 2001))
+            name_old, self.government_holidays, (f"{year}-10-25" for year in range(1998, 2001))
         )
-        self.assertNoHolidayName(name, self.government_holidays, range(2001, 2050))
+        self.assertNoHolidayName(name_old, self.government_holidays, range(2001, 2050))
 
         # School Holidays.
         self.assertHolidayName(
-            name, self.school_holidays, (f"{year}-10-25" for year in range(1998, 2001))
+            name_old, self.school_holidays, (f"{year}-10-25" for year in range(1998, 2001))
         )
-        self.assertNoHolidayName(name, self.school_holidays, range(2001, 2050))
+        self.assertNoHolidayName(name_old, self.school_holidays, range(2001, 2050))
 
         # Workdays.
         self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-10-25" for year in range(2001, 2050))
+            name_old, self.workday_holidays, (f"{year}-10-25" for year in range(2001, 2025))
+        )
+        self.assertNoHolidayName(
+            name_old, self.workday_holidays, range(1998, 2000), range(2025, 2050)
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(1998, 2000))
-        self.assertNoHolidayName(name)
 
     def test_late_president_chiang_kai_sheks_birthday(self):
         name = "先總統　蔣公誕辰紀念日"
@@ -703,6 +723,10 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
     def test_constitution_day(self):
         name = "行憲紀念日"
 
+        # Public Holidays.
+        self.assertHolidayName(name, (f"{year}-12-25" for year in range(2025, 2050)))
+        self.assertNoHolidayName(name, range(1998, 2025))
+
         # Government Holidays.
         self.assertHolidayName(
             name, self.government_holidays, (f"{year}-12-25" for year in range(1998, 2001))
@@ -717,10 +741,9 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
 
         # Workdays.
         self.assertHolidayName(
-            name, self.workday_holidays, (f"{year}-12-25" for year in range(2001, 2050))
+            name, self.workday_holidays, (f"{year}-12-25" for year in range(2001, 2025))
         )
-        self.assertNoHolidayName(name, self.workday_holidays, range(1998, 2000))
-        self.assertNoHolidayName(name)
+        self.assertNoHolidayName(name, self.workday_holidays, range(1998, 2000), range(2025, 2050))
 
     def test_1998(self):
         self.assertHolidays(
@@ -1248,8 +1271,11 @@ class TestTaiwan(CommonCountryTests, WorkingDayTests, TestCase):
             ("2025-04-04", "兒童節; 民族掃墓節"),
             ("2025-05-30", "端午節（慶祝）"),
             ("2025-05-31", "端午節"),
+            ("2025-09-28", "孔子誕辰紀念日"),
             ("2025-10-06", "中秋節"),
             ("2025-10-10", "國慶日"),
+            ("2025-10-25", "臺灣光復暨金門古寧頭大捷紀念日"),
+            ("2025-12-25", "行憲紀念日"),
         )
 
     def test_l10n_default(self):
